@@ -10,16 +10,17 @@ class Configuration(ModelSingleton, ModelSQL, ModelView):
     _description = __doc__
 
     purchase_sequence = fields.Property(fields.Many2One('ir.sequence',
-        'Purchase Reference Sequence', domain=[
-            ('company', 'in', [Eval('company'), False]),
-            ('code', '=', 'purchase.purchase'),
-        ], required=True))
+            'Purchase Reference Sequence', domain=[
+                ('company', 'in',
+                    [Eval('context', {}).get('company', 0), False]),
+                ('code', '=', 'purchase.purchase'),
+                ], required=True))
     purchase_invoice_method = fields.Property(fields.Selection([
-        ('manual', 'Manual'),
-        ('order', 'Based On Order'),
-        ('shipment', 'Based On Shipment'),
-    ], 'Invoice Method', states={
-        'required': Bool(Eval('company')),
-    }))
+                ('manual', 'Manual'),
+                ('order', 'Based On Order'),
+                ('shipment', 'Based On Shipment'),
+                ], 'Invoice Method', states={
+                'required': Bool(Eval('context', {}).get('company', 0)),
+                }))
 
 Configuration()
